Crate anyxml_datetime

Crate anyxml_datetime 

A simple implementation of datetime format as defined in XML Schema Part 2: Datatypes Second Edition Appendix D ISO 8601 Date and Time Formats.

I do not target full ISO 8601 format support.

BCE year notation

This crate follows the older ISO 8601 referenced by XML Schema 1.0, which diverges from the BCE notation in the current ISO 8601 standard.
In the current ISO 8601 standard, “0000” denotes the year 1 BC, and “-0001” denotes the year 2 BC. However, in the older ISO 8601 referenced by the schema specification this crate follows, “0000” is an invalid year notation, and “-0001” indicates the year 1 BC.
Since XML Schema 1.1 now conforms to the current ISO 8601, this crate may follow the new notation in the future.

Structs

Date
DateTime
DateTimeError
Duration
GDay
GMonth
GMonthDay
GYear
GYearMonth
Time
TimeZone

Enums

ErrorKind
ErrorSegment